@@ -8,13 +8,14 @@ def scale(points, scale_factor=(1, 1, 1)):
     return points
 
 
-def rotate_around_axis(points, axis, angle):
+def rotate_around_axis(points, axis, angle, center_point=None):
     """
     Return the rotation matrix associated with counterclockwise rotation about
     the given axis by angle in radians.
     https://stackoverflow.com/questions/6802577/rotation-of-3d-vector
     """
-    center_point = points[:, :3].mean(axis=0).astype(points[:, :3].dtype)
+    if center_point is None:
+        center_point = points[:, :3].mean(axis=0).astype(points[:, :3].dtype)
     axis = axis / np.sqrt(np.dot(axis, axis))
     a = np.cos(angle / 2.0)
     b, c, d = -axis * np.sin(angle / 2.0)
@@ -69,3 +70,10 @@ def center(points, origin=(0, 0, 0)):
 def move(points, offset=(0, 0, 0)):
     points[:, :3] = points[:, :3] + offset
     return points
+
+
+def flip_coordinates(points, axis):
+    axis = np.argmax(axis)
+    coord_max = np.max(points[:, axis])
+    points[:, axis] = coord_max - points[:, axis]
+    return points
